# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/core/connection/v1/tx.proto',
  package='ibc.core.connection.v1',
  syntax='proto3',
  serialized_options=b'Z<github.com/cosmos/ibc-go/v2/modules/core/03-connection/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fibc/core/connection/v1/tx.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1fibc/core/client/v1/client.proto\x1a\'ibc/core/connection/v1/connection.proto\"\xfd\x01\n\x15MsgConnectionOpenInit\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12@\n\x0c\x63ounterparty\x18\x02 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12\x30\n\x07version\x18\x03 \x01(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12-\n\x0c\x64\x65lay_period\x18\x04 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"delay_period\"\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgConnectionOpenInitResponse\"\xe9\x05\n\x14MsgConnectionOpenTry\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x41\n\x16previous_connection_id\x18\x02 \x01(\tB!\xf2\xde\x1f\x1dyaml:\"previous_connection_id\"\x12\x43\n\x0c\x63lient_state\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:\"client_state\"\x12@\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12-\n\x0c\x64\x65lay_period\x18\x05 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"delay_period\"\x12`\n\x15\x63ounterparty_versions\x18\x06 \x03(\x0b\x32\x1f.ibc.core.connection.v1.VersionB \xf2\xde\x1f\x1cyaml:\"counterparty_versions\"\x12M\n\x0cproof_height\x18\x07 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12)\n\nproof_init\x18\x08 \x01(\x0c\x42\x15\xf2\xde\x1f\x11yaml:\"proof_init\"\x12-\n\x0cproof_client\x18\t \x01(\x0c\x42\x17\xf2\xde\x1f\x13yaml:\"proof_client\"\x12\x33\n\x0fproof_consensus\x18\n \x01(\x0c\x42\x1a\xf2\xde\x1f\x16yaml:\"proof_consensus\"\x12U\n\x10\x63onsensus_height\x18\x0b \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1f\xf2\xde\x1f\x17yaml:\"consensus_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x0c \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgConnectionOpenTryResponse\"\xd6\x04\n\x14MsgConnectionOpenAck\x12/\n\rconnection_id\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12I\n\x1a\x63ounterparty_connection_id\x18\x02 \x01(\tB%\xf2\xde\x1f!yaml:\"counterparty_connection_id\"\x12\x30\n\x07version\x18\x03 \x01(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12\x43\n\x0c\x63lient_state\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:\"client_state\"\x12M\n\x0cproof_height\x18\x05 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\'\n\tproof_try\x18\x06 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"proof_try\"\x12-\n\x0cproof_client\x18\x07 \x01(\x0c\x42\x17\xf2\xde\x1f\x13yaml:\"proof_client\"\x12\x33\n\x0fproof_consensus\x18\x08 \x01(\x0c\x42\x1a\xf2\xde\x1f\x16yaml:\"proof_consensus\"\x12U\n\x10\x63onsensus_height\x18\t \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1f\xf2\xde\x1f\x17yaml:\"consensus_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\n \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgConnectionOpenAckResponse\"\xdd\x01\n\x18MsgConnectionOpenConfirm\x12/\n\rconnection_id\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12\'\n\tproof_ack\x18\x02 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"proof_ack\"\x12M\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x04 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\"\n MsgConnectionOpenConfirmResponse2\xf9\x03\n\x03Msg\x12z\n\x12\x43onnectionOpenInit\x12-.ibc.core.connection.v1.MsgConnectionOpenInit\x1a\x35.ibc.core.connection.v1.MsgConnectionOpenInitResponse\x12w\n\x11\x43onnectionOpenTry\x12,.ibc.core.connection.v1.MsgConnectionOpenTry\x1a\x34.ibc.core.connection.v1.MsgConnectionOpenTryResponse\x12w\n\x11\x43onnectionOpenAck\x12,.ibc.core.connection.v1.MsgConnectionOpenAck\x1a\x34.ibc.core.connection.v1.MsgConnectionOpenAckResponse\x12\x83\x01\n\x15\x43onnectionOpenConfirm\x12\x30.ibc.core.connection.v1.MsgConnectionOpenConfirm\x1a\x38.ibc.core.connection.v1.MsgConnectionOpenConfirmResponseB>Z<github.com/cosmos/ibc-go/v2/modules/core/03-connection/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,ibc_dot_core_dot_client_dot_v1_dot_client__pb2.DESCRIPTOR,ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2.DESCRIPTOR,])




_MSGCONNECTIONOPENINIT = _descriptor.Descriptor(
  name='MsgConnectionOpenInit',
  full_name='ibc.core.connection.v1.MsgConnectionOpenInit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ibc.core.connection.v1.MsgConnectionOpenInit.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"client_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty', full_name='ibc.core.connection.v1.MsgConnectionOpenInit.counterparty', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ibc.core.connection.v1.MsgConnectionOpenInit.version', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_period', full_name='ibc.core.connection.v1.MsgConnectionOpenInit.delay_period', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"delay_period\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.connection.v1.MsgConnectionOpenInit.signer', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=436,
)


_MSGCONNECTIONOPENINITRESPONSE = _descriptor.Descriptor(
  name='MsgConnectionOpenInitResponse',
  full_name='ibc.core.connection.v1.MsgConnectionOpenInitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=469,
)


_MSGCONNECTIONOPENTRY = _descriptor.Descriptor(
  name='MsgConnectionOpenTry',
  full_name='ibc.core.connection.v1.MsgConnectionOpenTry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"client_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_connection_id', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.previous_connection_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\035yaml:\"previous_connection_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_state', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.client_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"client_state\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.counterparty', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_period', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.delay_period', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"delay_period\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty_versions', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.counterparty_versions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\034yaml:\"counterparty_versions\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.proof_height', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_init', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.proof_init', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"proof_init\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_client', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.proof_client', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_client\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_consensus', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.proof_consensus', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"proof_consensus\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensus_height', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.consensus_height', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\027yaml:\"consensus_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.connection.v1.MsgConnectionOpenTry.signer', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=472,
  serialized_end=1217,
)


_MSGCONNECTIONOPENTRYRESPONSE = _descriptor.Descriptor(
  name='MsgConnectionOpenTryResponse',
  full_name='ibc.core.connection.v1.MsgConnectionOpenTryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1219,
  serialized_end=1249,
)


_MSGCONNECTIONOPENACK = _descriptor.Descriptor(
  name='MsgConnectionOpenAck',
  full_name='ibc.core.connection.v1.MsgConnectionOpenAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='ibc.core.connection.v1.MsgConnectionOpenAck.connection_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"connection_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty_connection_id', full_name='ibc.core.connection.v1.MsgConnectionOpenAck.counterparty_connection_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037!yaml:\"counterparty_connection_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ibc.core.connection.v1.MsgConnectionOpenAck.version', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_state', full_name='ibc.core.connection.v1.MsgConnectionOpenAck.client_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"client_state\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.connection.v1.MsgConnectionOpenAck.proof_height', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_try', full_name='ibc.core.connection.v1.MsgConnectionOpenAck.proof_try', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"proof_try\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_client', full_name='ibc.core.connection.v1.MsgConnectionOpenAck.proof_client', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_client\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_consensus', full_name='ibc.core.connection.v1.MsgConnectionOpenAck.proof_consensus', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"proof_consensus\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensus_height', full_name='ibc.core.connection.v1.MsgConnectionOpenAck.consensus_height', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\027yaml:\"consensus_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.connection.v1.MsgConnectionOpenAck.signer', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1252,
  serialized_end=1850,
)


_MSGCONNECTIONOPENACKRESPONSE = _descriptor.Descriptor(
  name='MsgConnectionOpenAckResponse',
  full_name='ibc.core.connection.v1.MsgConnectionOpenAckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=1882,
)


_MSGCONNECTIONOPENCONFIRM = _descriptor.Descriptor(
  name='MsgConnectionOpenConfirm',
  full_name='ibc.core.connection.v1.MsgConnectionOpenConfirm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='ibc.core.connection.v1.MsgConnectionOpenConfirm.connection_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"connection_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_ack', full_name='ibc.core.connection.v1.MsgConnectionOpenConfirm.proof_ack', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"proof_ack\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.connection.v1.MsgConnectionOpenConfirm.proof_height', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.connection.v1.MsgConnectionOpenConfirm.signer', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1885,
  serialized_end=2106,
)


_MSGCONNECTIONOPENCONFIRMRESPONSE = _descriptor.Descriptor(
  name='MsgConnectionOpenConfirmResponse',
  full_name='ibc.core.connection.v1.MsgConnectionOpenConfirmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2108,
  serialized_end=2142,
)

_MSGCONNECTIONOPENINIT.fields_by_name['counterparty'].message_type = ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2._COUNTERPARTY
_MSGCONNECTIONOPENINIT.fields_by_name['version'].message_type = ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2._VERSION
_MSGCONNECTIONOPENTRY.fields_by_name['client_state'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_MSGCONNECTIONOPENTRY.fields_by_name['counterparty'].message_type = ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2._COUNTERPARTY
_MSGCONNECTIONOPENTRY.fields_by_name['counterparty_versions'].message_type = ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2._VERSION
_MSGCONNECTIONOPENTRY.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGCONNECTIONOPENTRY.fields_by_name['consensus_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGCONNECTIONOPENACK.fields_by_name['version'].message_type = ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2._VERSION
_MSGCONNECTIONOPENACK.fields_by_name['client_state'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_MSGCONNECTIONOPENACK.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGCONNECTIONOPENACK.fields_by_name['consensus_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGCONNECTIONOPENCONFIRM.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
DESCRIPTOR.message_types_by_name['MsgConnectionOpenInit'] = _MSGCONNECTIONOPENINIT
DESCRIPTOR.message_types_by_name['MsgConnectionOpenInitResponse'] = _MSGCONNECTIONOPENINITRESPONSE
DESCRIPTOR.message_types_by_name['MsgConnectionOpenTry'] = _MSGCONNECTIONOPENTRY
DESCRIPTOR.message_types_by_name['MsgConnectionOpenTryResponse'] = _MSGCONNECTIONOPENTRYRESPONSE
DESCRIPTOR.message_types_by_name['MsgConnectionOpenAck'] = _MSGCONNECTIONOPENACK
DESCRIPTOR.message_types_by_name['MsgConnectionOpenAckResponse'] = _MSGCONNECTIONOPENACKRESPONSE
DESCRIPTOR.message_types_by_name['MsgConnectionOpenConfirm'] = _MSGCONNECTIONOPENCONFIRM
DESCRIPTOR.message_types_by_name['MsgConnectionOpenConfirmResponse'] = _MSGCONNECTIONOPENCONFIRMRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgConnectionOpenInit = _reflection.GeneratedProtocolMessageType('MsgConnectionOpenInit', (_message.Message,), {
  'DESCRIPTOR' : _MSGCONNECTIONOPENINIT,
  '__module__' : 'ibc.core.connection.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.MsgConnectionOpenInit)
  })
_sym_db.RegisterMessage(MsgConnectionOpenInit)

MsgConnectionOpenInitResponse = _reflection.GeneratedProtocolMessageType('MsgConnectionOpenInitResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCONNECTIONOPENINITRESPONSE,
  '__module__' : 'ibc.core.connection.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.MsgConnectionOpenInitResponse)
  })
_sym_db.RegisterMessage(MsgConnectionOpenInitResponse)

MsgConnectionOpenTry = _reflection.GeneratedProtocolMessageType('MsgConnectionOpenTry', (_message.Message,), {
  'DESCRIPTOR' : _MSGCONNECTIONOPENTRY,
  '__module__' : 'ibc.core.connection.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.MsgConnectionOpenTry)
  })
_sym_db.RegisterMessage(MsgConnectionOpenTry)

MsgConnectionOpenTryResponse = _reflection.GeneratedProtocolMessageType('MsgConnectionOpenTryResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCONNECTIONOPENTRYRESPONSE,
  '__module__' : 'ibc.core.connection.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.MsgConnectionOpenTryResponse)
  })
_sym_db.RegisterMessage(MsgConnectionOpenTryResponse)

MsgConnectionOpenAck = _reflection.GeneratedProtocolMessageType('MsgConnectionOpenAck', (_message.Message,), {
  'DESCRIPTOR' : _MSGCONNECTIONOPENACK,
  '__module__' : 'ibc.core.connection.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.MsgConnectionOpenAck)
  })
_sym_db.RegisterMessage(MsgConnectionOpenAck)

MsgConnectionOpenAckResponse = _reflection.GeneratedProtocolMessageType('MsgConnectionOpenAckResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCONNECTIONOPENACKRESPONSE,
  '__module__' : 'ibc.core.connection.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.MsgConnectionOpenAckResponse)
  })
_sym_db.RegisterMessage(MsgConnectionOpenAckResponse)

MsgConnectionOpenConfirm = _reflection.GeneratedProtocolMessageType('MsgConnectionOpenConfirm', (_message.Message,), {
  'DESCRIPTOR' : _MSGCONNECTIONOPENCONFIRM,
  '__module__' : 'ibc.core.connection.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.MsgConnectionOpenConfirm)
  })
_sym_db.RegisterMessage(MsgConnectionOpenConfirm)

MsgConnectionOpenConfirmResponse = _reflection.GeneratedProtocolMessageType('MsgConnectionOpenConfirmResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCONNECTIONOPENCONFIRMRESPONSE,
  '__module__' : 'ibc.core.connection.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.MsgConnectionOpenConfirmResponse)
  })
_sym_db.RegisterMessage(MsgConnectionOpenConfirmResponse)


DESCRIPTOR._options = None
_MSGCONNECTIONOPENINIT.fields_by_name['client_id']._options = None
_MSGCONNECTIONOPENINIT.fields_by_name['counterparty']._options = None
_MSGCONNECTIONOPENINIT.fields_by_name['delay_period']._options = None
_MSGCONNECTIONOPENINIT._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['client_id']._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['previous_connection_id']._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['client_state']._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['counterparty']._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['delay_period']._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['counterparty_versions']._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['proof_height']._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['proof_init']._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['proof_client']._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['proof_consensus']._options = None
_MSGCONNECTIONOPENTRY.fields_by_name['consensus_height']._options = None
_MSGCONNECTIONOPENTRY._options = None
_MSGCONNECTIONOPENACK.fields_by_name['connection_id']._options = None
_MSGCONNECTIONOPENACK.fields_by_name['counterparty_connection_id']._options = None
_MSGCONNECTIONOPENACK.fields_by_name['client_state']._options = None
_MSGCONNECTIONOPENACK.fields_by_name['proof_height']._options = None
_MSGCONNECTIONOPENACK.fields_by_name['proof_try']._options = None
_MSGCONNECTIONOPENACK.fields_by_name['proof_client']._options = None
_MSGCONNECTIONOPENACK.fields_by_name['proof_consensus']._options = None
_MSGCONNECTIONOPENACK.fields_by_name['consensus_height']._options = None
_MSGCONNECTIONOPENACK._options = None
_MSGCONNECTIONOPENCONFIRM.fields_by_name['connection_id']._options = None
_MSGCONNECTIONOPENCONFIRM.fields_by_name['proof_ack']._options = None
_MSGCONNECTIONOPENCONFIRM.fields_by_name['proof_height']._options = None
_MSGCONNECTIONOPENCONFIRM._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='ibc.core.connection.v1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2145,
  serialized_end=2650,
  methods=[
  _descriptor.MethodDescriptor(
    name='ConnectionOpenInit',
    full_name='ibc.core.connection.v1.Msg.ConnectionOpenInit',
    index=0,
    containing_service=None,
    input_type=_MSGCONNECTIONOPENINIT,
    output_type=_MSGCONNECTIONOPENINITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConnectionOpenTry',
    full_name='ibc.core.connection.v1.Msg.ConnectionOpenTry',
    index=1,
    containing_service=None,
    input_type=_MSGCONNECTIONOPENTRY,
    output_type=_MSGCONNECTIONOPENTRYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConnectionOpenAck',
    full_name='ibc.core.connection.v1.Msg.ConnectionOpenAck',
    index=2,
    containing_service=None,
    input_type=_MSGCONNECTIONOPENACK,
    output_type=_MSGCONNECTIONOPENACKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConnectionOpenConfirm',
    full_name='ibc.core.connection.v1.Msg.ConnectionOpenConfirm',
    index=3,
    containing_service=None,
    input_type=_MSGCONNECTIONOPENCONFIRM,
    output_type=_MSGCONNECTIONOPENCONFIRMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/bank/v1beta1/authz.proto',
  package='cosmos.bank.v1beta1',
  syntax='proto3',
  serialized_options=b'Z)github.com/cosmos/cosmos-sdk/x/bank/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x63osmos/bank/v1beta1/authz.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x88\x01\n\x11SendAuthorization\x12`\n\x0bspend_limit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x11\xd2\xb4-\rAuthorizationB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos__proto_dot_cosmos__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_SENDAUTHORIZATION = _descriptor.Descriptor(
  name='SendAuthorization',
  full_name='cosmos.bank.v1beta1.SendAuthorization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spend_limit', full_name='cosmos.bank.v1beta1.SendAuthorization.spend_limit', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=274,
)

_SENDAUTHORIZATION.fields_by_name['spend_limit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['SendAuthorization'] = _SENDAUTHORIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SendAuthorization = _reflection.GeneratedProtocolMessageType('SendAuthorization', (_message.Message,), {
  'DESCRIPTOR' : _SENDAUTHORIZATION,
  '__module__' : 'cosmos.bank.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.SendAuthorization)
  })
_sym_db.RegisterMessage(SendAuthorization)


DESCRIPTOR._options = None
_SENDAUTHORIZATION.fields_by_name['spend_limit']._options = None
_SENDAUTHORIZATION._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2018-2021 Fetch.AI Limited
#   Modifications copyright (C) 2022 Cros-Nest
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------

"""Interface for the Mint functionality of CosmosSDK."""

from abc import ABC, abstractmethod

from cosmpy.protos.cosmos.mint.v1beta1.query_pb2 import (
    QueryAnnualProvisionsResponse,
    QueryInflationResponse,
    QueryParamsResponse,
)


class Mint(ABC):
    """Mint abstract class."""

    @abstractmethod
    def AnnualProvisions(self) -> QueryAnnualProvisionsResponse:
        """
        AnnualProvisions current minting annual provisions value.
        :return: a QueryAnnualProvisionsResponse instance
        """

    @abstractmethod
    def Inflation(self) -> QueryInflationResponse:
        """
        Inflation returns the current minting inflation value.
        :return: a QueryInflationResponse instance
        """

    @abstractmethod
    def Params(self) -> QueryParamsResponse:
        """
        Params returns the total set of minting parameters.
        :return: QueryParamsResponse
        """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/tendermint/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from tendermint.p2p import types_pb2 as tendermint_dot_p2p_dot_types__pb2
from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/base/tendermint/v1beta1/query.proto',
  package='cosmos.base.tendermint.v1beta1',
  syntax='proto3',
  serialized_options=b'Z2github.com/cosmos/cosmos-sdk/client/grpc/tmservice',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*cosmos/base/tendermint/v1beta1/query.proto\x12\x1e\x63osmos.base.tendermint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1atendermint/p2p/types.proto\x1a\x1ctendermint/types/block.proto\x1a\x1ctendermint/types/types.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\"l\n\x1eGetValidatorSetByHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xb3\x01\n\x1fGetValidatorSetByHeightResponse\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x03\x12=\n\nvalidators\x18\x02 \x03(\x0b\x32).cosmos.base.tendermint.v1beta1.Validator\x12;\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"Z\n\x1cGetLatestValidatorSetRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xb1\x01\n\x1dGetLatestValidatorSetResponse\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x03\x12=\n\nvalidators\x18\x02 \x03(\x0b\x32).cosmos.base.tendermint.v1beta1.Validator\x12;\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"t\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12%\n\x07pub_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x14\n\x0cvoting_power\x18\x03 \x01(\x03\x12\x19\n\x11proposer_priority\x18\x04 \x01(\x03\")\n\x17GetBlockByHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"o\n\x18GetBlockByHeightResponse\x12+\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x19.tendermint.types.BlockID\x12&\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.tendermint.types.Block\"\x17\n\x15GetLatestBlockRequest\"m\n\x16GetLatestBlockResponse\x12+\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x19.tendermint.types.BlockID\x12&\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.tendermint.types.Block\"\x13\n\x11GetSyncingRequest\"%\n\x12GetSyncingResponse\x12\x0f\n\x07syncing\x18\x01 \x01(\x08\"\x14\n\x12GetNodeInfoRequest\"\x9b\x01\n\x13GetNodeInfoResponse\x12:\n\x11\x64\x65\x66\x61ult_node_info\x18\x01 \x01(\x0b\x32\x1f.tendermint.p2p.DefaultNodeInfo\x12H\n\x13\x61pplication_version\x18\x02 \x01(\x0b\x32+.cosmos.base.tendermint.v1beta1.VersionInfo\"\xd2\x01\n\x0bVersionInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x12\n\ngit_commit\x18\x04 \x01(\t\x12\x12\n\nbuild_tags\x18\x05 \x01(\t\x12\x12\n\ngo_version\x18\x06 \x01(\t\x12:\n\nbuild_deps\x18\x07 \x03(\x0b\x32&.cosmos.base.tendermint.v1beta1.Module\x12\x1a\n\x12\x63osmos_sdk_version\x18\x08 \x01(\t\"4\n\x06Module\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0b\n\x03sum\x18\x03 \x01(\t2\x88\t\n\x07Service\x12\xa9\x01\n\x0bGetNodeInfo\x12\x32.cosmos.base.tendermint.v1beta1.GetNodeInfoRequest\x1a\x33.cosmos.base.tendermint.v1beta1.GetNodeInfoResponse\"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/base/tendermint/v1beta1/node_info\x12\xa4\x01\n\nGetSyncing\x12\x31.cosmos.base.tendermint.v1beta1.GetSyncingRequest\x1a\x32.cosmos.base.tendermint.v1beta1.GetSyncingResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/base/tendermint/v1beta1/syncing\x12\xb6\x01\n\x0eGetLatestBlock\x12\x35.cosmos.base.tendermint.v1beta1.GetLatestBlockRequest\x1a\x36.cosmos.base.tendermint.v1beta1.GetLatestBlockResponse\"5\x82\xd3\xe4\x93\x02/\x12-/cosmos/base/tendermint/v1beta1/blocks/latest\x12\xbe\x01\n\x10GetBlockByHeight\x12\x37.cosmos.base.tendermint.v1beta1.GetBlockByHeightRequest\x1a\x38.cosmos.base.tendermint.v1beta1.GetBlockByHeightResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//cosmos/base/tendermint/v1beta1/blocks/{height}\x12\xd2\x01\n\x15GetLatestValidatorSet\x12<.cosmos.base.tendermint.v1beta1.GetLatestValidatorSetRequest\x1a=.cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/tendermint/v1beta1/validatorsets/latest\x12\xda\x01\n\x17GetValidatorSetByHeight\x12>.cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightRequest\x1a?.cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/cosmos/base/tendermint/v1beta1/validatorsets/{height}B4Z2github.com/cosmos/cosmos-sdk/client/grpc/tmserviceb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,tendermint_dot_p2p_dot_types__pb2.DESCRIPTOR,tendermint_dot_types_dot_block__pb2.DESCRIPTOR,tendermint_dot_types_dot_types__pb2.DESCRIPTOR,cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2.DESCRIPTOR,])




_GETVALIDATORSETBYHEIGHTREQUEST = _descriptor.Descriptor(
  name='GetValidatorSetByHeightRequest',
  full_name='cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightRequest.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=397,
)


_GETVALIDATORSETBYHEIGHTRESPONSE = _descriptor.Descriptor(
  name='GetValidatorSetByHeightResponse',
  full_name='cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_height', full_name='cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse.block_height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validators', full_name='cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse.validators', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse.pagination', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=579,
)


_GETLATESTVALIDATORSETREQUEST = _descriptor.Descriptor(
  name='GetLatestValidatorSetRequest',
  full_name='cosmos.base.tendermint.v1beta1.GetLatestValidatorSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.base.tendermint.v1beta1.GetLatestValidatorSetRequest.pagination', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=671,
)


_GETLATESTVALIDATORSETRESPONSE = _descriptor.Descriptor(
  name='GetLatestValidatorSetResponse',
  full_name='cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_height', full_name='cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse.block_height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validators', full_name='cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse.validators', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse.pagination', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=851,
)


_VALIDATOR = _descriptor.Descriptor(
  name='Validator',
  full_name='cosmos.base.tendermint.v1beta1.Validator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmos.base.tendermint.v1beta1.Validator.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='cosmos.base.tendermint.v1beta1.Validator.pub_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voting_power', full_name='cosmos.base.tendermint.v1beta1.Validator.voting_power', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposer_priority', full_name='cosmos.base.tendermint.v1beta1.Validator.proposer_priority', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=969,
)


_GETBLOCKBYHEIGHTREQUEST = _descriptor.Descriptor(
  name='GetBlockByHeightRequest',
  full_name='cosmos.base.tendermint.v1beta1.GetBlockByHeightRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='cosmos.base.tendermint.v1beta1.GetBlockByHeightRequest.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1012,
)


_GETBLOCKBYHEIGHTRESPONSE = _descriptor.Descriptor(
  name='GetBlockByHeightResponse',
  full_name='cosmos.base.tendermint.v1beta1.GetBlockByHeightResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='cosmos.base.tendermint.v1beta1.GetBlockByHeightResponse.block_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block', full_name='cosmos.base.tendermint.v1beta1.GetBlockByHeightResponse.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1014,
  serialized_end=1125,
)


_GETLATESTBLOCKREQUEST = _descriptor.Descriptor(
  name='GetLatestBlockRequest',
  full_name='cosmos.base.tendermint.v1beta1.GetLatestBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1150,
)


_GETLATESTBLOCKRESPONSE = _descriptor.Descriptor(
  name='GetLatestBlockResponse',
  full_name='cosmos.base.tendermint.v1beta1.GetLatestBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='cosmos.base.tendermint.v1beta1.GetLatestBlockResponse.block_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block', full_name='cosmos.base.tendermint.v1beta1.GetLatestBlockResponse.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1152,
  serialized_end=1261,
)


_GETSYNCINGREQUEST = _descriptor.Descriptor(
  name='GetSyncingRequest',
  full_name='cosmos.base.tendermint.v1beta1.GetSyncingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1263,
  serialized_end=1282,
)


_GETSYNCINGRESPONSE = _descriptor.Descriptor(
  name='GetSyncingResponse',
  full_name='cosmos.base.tendermint.v1beta1.GetSyncingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='syncing', full_name='cosmos.base.tendermint.v1beta1.GetSyncingResponse.syncing', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1321,
)


_GETNODEINFOREQUEST = _descriptor.Descriptor(
  name='GetNodeInfoRequest',
  full_name='cosmos.base.tendermint.v1beta1.GetNodeInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1343,
)


_GETNODEINFORESPONSE = _descriptor.Descriptor(
  name='GetNodeInfoResponse',
  full_name='cosmos.base.tendermint.v1beta1.GetNodeInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_node_info', full_name='cosmos.base.tendermint.v1beta1.GetNodeInfoResponse.default_node_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_version', full_name='cosmos.base.tendermint.v1beta1.GetNodeInfoResponse.application_version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1501,
)


_VERSIONINFO = _descriptor.Descriptor(
  name='VersionInfo',
  full_name='cosmos.base.tendermint.v1beta1.VersionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cosmos.base.tendermint.v1beta1.VersionInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='cosmos.base.tendermint.v1beta1.VersionInfo.app_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='cosmos.base.tendermint.v1beta1.VersionInfo.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='git_commit', full_name='cosmos.base.tendermint.v1beta1.VersionInfo.git_commit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_tags', full_name='cosmos.base.tendermint.v1beta1.VersionInfo.build_tags', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='go_version', full_name='cosmos.base.tendermint.v1beta1.VersionInfo.go_version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_deps', full_name='cosmos.base.tendermint.v1beta1.VersionInfo.build_deps', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_sdk_version', full_name='cosmos.base.tendermint.v1beta1.VersionInfo.cosmos_sdk_version', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1504,
  serialized_end=1714,
)


_MODULE = _descriptor.Descriptor(
  name='Module',
  full_name='cosmos.base.tendermint.v1beta1.Module',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='cosmos.base.tendermint.v1beta1.Module.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='cosmos.base.tendermint.v1beta1.Module.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sum', full_name='cosmos.base.tendermint.v1beta1.Module.sum', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1716,
  serialized_end=1768,
)

_GETVALIDATORSETBYHEIGHTREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_GETVALIDATORSETBYHEIGHTRESPONSE.fields_by_name['validators'].message_type = _VALIDATOR
_GETVALIDATORSETBYHEIGHTRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_GETLATESTVALIDATORSETREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_GETLATESTVALIDATORSETRESPONSE.fields_by_name['validators'].message_type = _VALIDATOR
_GETLATESTVALIDATORSETRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_VALIDATOR.fields_by_name['pub_key'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_GETBLOCKBYHEIGHTRESPONSE.fields_by_name['block_id'].message_type = tendermint_dot_types_dot_types__pb2._BLOCKID
_GETBLOCKBYHEIGHTRESPONSE.fields_by_name['block'].message_type = tendermint_dot_types_dot_block__pb2._BLOCK
_GETLATESTBLOCKRESPONSE.fields_by_name['block_id'].message_type = tendermint_dot_types_dot_types__pb2._BLOCKID
_GETLATESTBLOCKRESPONSE.fields_by_name['block'].message_type = tendermint_dot_types_dot_block__pb2._BLOCK
_GETNODEINFORESPONSE.fields_by_name['default_node_info'].message_type = tendermint_dot_p2p_dot_types__pb2._DEFAULTNODEINFO
_GETNODEINFORESPONSE.fields_by_name['application_version'].message_type = _VERSIONINFO
_VERSIONINFO.fields_by_name['build_deps'].message_type = _MODULE
DESCRIPTOR.message_types_by_name['GetValidatorSetByHeightRequest'] = _GETVALIDATORSETBYHEIGHTREQUEST
DESCRIPTOR.message_types_by_name['GetValidatorSetByHeightResponse'] = _GETVALIDATORSETBYHEIGHTRESPONSE
DESCRIPTOR.message_types_by_name['GetLatestValidatorSetRequest'] = _GETLATESTVALIDATORSETREQUEST
DESCRIPTOR.message_types_by_name['GetLatestValidatorSetResponse'] = _GETLATESTVALIDATORSETRESPONSE
DESCRIPTOR.message_types_by_name['Validator'] = _VALIDATOR
DESCRIPTOR.message_types_by_name['GetBlockByHeightRequest'] = _GETBLOCKBYHEIGHTREQUEST
DESCRIPTOR.message_types_by_name['GetBlockByHeightResponse'] = _GETBLOCKBYHEIGHTRESPONSE
DESCRIPTOR.message_types_by_name['GetLatestBlockRequest'] = _GETLATESTBLOCKREQUEST
DESCRIPTOR.message_types_by_name['GetLatestBlockResponse'] = _GETLATESTBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['GetSyncingRequest'] = _GETSYNCINGREQUEST
DESCRIPTOR.message_types_by_name['GetSyncingResponse'] = _GETSYNCINGRESPONSE
DESCRIPTOR.message_types_by_name['GetNodeInfoRequest'] = _GETNODEINFOREQUEST
DESCRIPTOR.message_types_by_name['GetNodeInfoResponse'] = _GETNODEINFORESPONSE
DESCRIPTOR.message_types_by_name['VersionInfo'] = _VERSIONINFO
DESCRIPTOR.message_types_by_name['Module'] = _MODULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetValidatorSetByHeightRequest = _reflection.GeneratedProtocolMessageType('GetValidatorSetByHeightRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVALIDATORSETBYHEIGHTREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightRequest)
  })
_sym_db.RegisterMessage(GetValidatorSetByHeightRequest)

GetValidatorSetByHeightResponse = _reflection.GeneratedProtocolMessageType('GetValidatorSetByHeightResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVALIDATORSETBYHEIGHTRESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse)
  })
_sym_db.RegisterMessage(GetValidatorSetByHeightResponse)

GetLatestValidatorSetRequest = _reflection.GeneratedProtocolMessageType('GetLatestValidatorSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTVALIDATORSETREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetLatestValidatorSetRequest)
  })
_sym_db.RegisterMessage(GetLatestValidatorSetRequest)

GetLatestValidatorSetResponse = _reflection.GeneratedProtocolMessageType('GetLatestValidatorSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTVALIDATORSETRESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse)
  })
_sym_db.RegisterMessage(GetLatestValidatorSetResponse)

Validator = _reflection.GeneratedProtocolMessageType('Validator', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATOR,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.Validator)
  })
_sym_db.RegisterMessage(Validator)

GetBlockByHeightRequest = _reflection.GeneratedProtocolMessageType('GetBlockByHeightRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKBYHEIGHTREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetBlockByHeightRequest)
  })
_sym_db.RegisterMessage(GetBlockByHeightRequest)

GetBlockByHeightResponse = _reflection.GeneratedProtocolMessageType('GetBlockByHeightResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKBYHEIGHTRESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetBlockByHeightResponse)
  })
_sym_db.RegisterMessage(GetBlockByHeightResponse)

GetLatestBlockRequest = _reflection.GeneratedProtocolMessageType('GetLatestBlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTBLOCKREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetLatestBlockRequest)
  })
_sym_db.RegisterMessage(GetLatestBlockRequest)

GetLatestBlockResponse = _reflection.GeneratedProtocolMessageType('GetLatestBlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTBLOCKRESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetLatestBlockResponse)
  })
_sym_db.RegisterMessage(GetLatestBlockResponse)

GetSyncingRequest = _reflection.GeneratedProtocolMessageType('GetSyncingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSYNCINGREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetSyncingRequest)
  })
_sym_db.RegisterMessage(GetSyncingRequest)

GetSyncingResponse = _reflection.GeneratedProtocolMessageType('GetSyncingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSYNCINGRESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetSyncingResponse)
  })
_sym_db.RegisterMessage(GetSyncingResponse)

GetNodeInfoRequest = _reflection.GeneratedProtocolMessageType('GetNodeInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEINFOREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetNodeInfoRequest)
  })
_sym_db.RegisterMessage(GetNodeInfoRequest)

GetNodeInfoResponse = _reflection.GeneratedProtocolMessageType('GetNodeInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEINFORESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetNodeInfoResponse)
  })
_sym_db.RegisterMessage(GetNodeInfoResponse)

VersionInfo = _reflection.GeneratedProtocolMessageType('VersionInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONINFO,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.VersionInfo)
  })
_sym_db.RegisterMessage(VersionInfo)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), {
  'DESCRIPTOR' : _MODULE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.Module)
  })
_sym_db.RegisterMessage(Module)


DESCRIPTOR._options = None

_SERVICE = _descriptor.ServiceDescriptor(
  name='Service',
  full_name='cosmos.base.tendermint.v1beta1.Service',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1771,
  serialized_end=2931,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetNodeInfo',
    full_name='cosmos.base.tendermint.v1beta1.Service.GetNodeInfo',
    index=0,
    containing_service=None,
    input_type=_GETNODEINFOREQUEST,
    output_type=_GETNODEINFORESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/cosmos/base/tendermint/v1beta1/node_info',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSyncing',
    full_name='cosmos.base.tendermint.v1beta1.Service.GetSyncing',
    index=1,
    containing_service=None,
    input_type=_GETSYNCINGREQUEST,
    output_type=_GETSYNCINGRESPONSE,
    serialized_options=b'\202\323\344\223\002)\022\'/cosmos/base/tendermint/v1beta1/syncing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLatestBlock',
    full_name='cosmos.base.tendermint.v1beta1.Service.GetLatestBlock',
    index=2,
    containing_service=None,
    input_type=_GETLATESTBLOCKREQUEST,
    output_type=_GETLATESTBLOCKRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/cosmos/base/tendermint/v1beta1/blocks/latest',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockByHeight',
    full_name='cosmos.base.tendermint.v1beta1.Service.GetBlockByHeight',
    index=3,
    containing_service=None,
    input_type=_GETBLOCKBYHEIGHTREQUEST,
    output_type=_GETBLOCKBYHEIGHTRESPONSE,
    serialized_options=b'\202\323\344\223\0021\022//cosmos/base/tendermint/v1beta1/blocks/{height}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLatestValidatorSet',
    full_name='cosmos.base.tendermint.v1beta1.Service.GetLatestValidatorSet',
    index=4,
    containing_service=None,
    input_type=_GETLATESTVALIDATORSETREQUEST,
    output_type=_GETLATESTVALIDATORSETRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/cosmos/base/tendermint/v1beta1/validatorsets/latest',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetValidatorSetByHeight',
    full_name='cosmos.base.tendermint.v1beta1.Service.GetValidatorSetByHeight',
    index=5,
    containing_service=None,
    input_type=_GETVALIDATORSETBYHEIGHTREQUEST,
    output_type=_GETVALIDATORSETBYHEIGHTRESPONSE,
    serialized_options=b'\202\323\344\223\0028\0226/cosmos/base/tendermint/v1beta1/validatorsets/{height}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICE)

DESCRIPTOR.services_by_name['Service'] = _SERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2018-2021 Fetch.AI Limited
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------
import argparse
from datetime import datetime, timedelta

from google.protobuf import any_pb2, timestamp_pb2

from cosmpy.aerial.client import LedgerClient, NetworkConfig
from cosmpy.aerial.client.utils import prepare_and_broadcast_basic_transaction
from cosmpy.aerial.tx import Transaction
from cosmpy.aerial.wallet import LocalWallet
from cosmpy.crypto.keypairs import PrivateKey
from cosmpy.protos.cosmos.authz.v1beta1.authz_pb2 import Grant
from cosmpy.protos.cosmos.authz.v1beta1.tx_pb2 import MsgGrant
from cosmpy.protos.cosmos.bank.v1beta1.authz_pb2 import SendAuthorization
from cosmpy.protos.cosmos.base.v1beta1.coin_pb2 import Coin


def _parse_commandline():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "authz_address",
        help="address that will be granted authorization to send tokens from wallet",
    )
    parser.add_argument(
        "total_authz_time",
        type=int,
        nargs="?",
        default=10,
        help="authorization time for authz_address in minutes",
    )
    parser.add_argument(
        "spend_limit",
        type=int,
        nargs="?",
        default=1000000000000000000,
        help="maximum tokens that authz_wallet will be able to spend from wallet",
    )

    return parser.parse_args()


def main():
    args = _parse_commandline()

    wallet = LocalWallet(PrivateKey("F7w1yHq1QIcQiSqV27YSwk+i1i+Y4JMKhkpawCQIh6s="))

    authz_address = args.authz_address

    ledger = LedgerClient(NetworkConfig.latest_stable_testnet())

    total_authz_time = args.total_authz_time

    amount = args.spend_limit

    spend_amount = Coin(amount=str(amount), denom="atestfet")

    # Authorize authz_wallet to send tokens from wallet
    authz_any = any_pb2.Any()
    authz_any.Pack(
        SendAuthorization(spend_limit=[spend_amount]),
        "",
    )

    expiry = timestamp_pb2.Timestamp()
    expiry.FromDatetime(datetime.now() + timedelta(seconds=total_authz_time * 60))
    grant = Grant(authorization=authz_any, expiration=expiry)

    msg = MsgGrant(
        granter=str(wallet.address()),
        grantee=authz_address,
        grant=grant,
    )

    tx = Transaction()
    tx.add_message(msg)

    tx = prepare_and_broadcast_basic_transaction(ledger, tx, wallet)
    tx.wait_to_complete()


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/evidence/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/evidence/v1beta1/tx.proto',
  package='cosmos.evidence.v1beta1',
  syntax='proto3',
  serialized_options=b'Z-github.com/cosmos/cosmos-sdk/x/evidence/types\250\342\036\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n cosmos/evidence/v1beta1/tx.proto\x12\x17\x63osmos.evidence.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"f\n\x11MsgSubmitEvidence\x12\x11\n\tsubmitter\x18\x01 \x01(\t\x12\x34\n\x08\x65vidence\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x0c\xca\xb4-\x08\x45vidence:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\")\n\x19MsgSubmitEvidenceResponse\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x32w\n\x03Msg\x12p\n\x0eSubmitEvidence\x12*.cosmos.evidence.v1beta1.MsgSubmitEvidence\x1a\x32.cosmos.evidence.v1beta1.MsgSubmitEvidenceResponseB3Z-github.com/cosmos/cosmos-sdk/x/evidence/types\xa8\xe2\x1e\x01\x62\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,cosmos__proto_dot_cosmos__pb2.DESCRIPTOR,])




_MSGSUBMITEVIDENCE = _descriptor.Descriptor(
  name='MsgSubmitEvidence',
  full_name='cosmos.evidence.v1beta1.MsgSubmitEvidence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submitter', full_name='cosmos.evidence.v1beta1.MsgSubmitEvidence.submitter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evidence', full_name='cosmos.evidence.v1beta1.MsgSubmitEvidence.evidence', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\264-\010Evidence', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=239,
)


_MSGSUBMITEVIDENCERESPONSE = _descriptor.Descriptor(
  name='MsgSubmitEvidenceResponse',
  full_name='cosmos.evidence.v1beta1.MsgSubmitEvidenceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='cosmos.evidence.v1beta1.MsgSubmitEvidenceResponse.hash', index=0,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=282,
)

_MSGSUBMITEVIDENCE.fields_by_name['evidence'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['MsgSubmitEvidence'] = _MSGSUBMITEVIDENCE
DESCRIPTOR.message_types_by_name['MsgSubmitEvidenceResponse'] = _MSGSUBMITEVIDENCERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgSubmitEvidence = _reflection.GeneratedProtocolMessageType('MsgSubmitEvidence', (_message.Message,), {
  'DESCRIPTOR' : _MSGSUBMITEVIDENCE,
  '__module__' : 'cosmos.evidence.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.evidence.v1beta1.MsgSubmitEvidence)
  })
_sym_db.RegisterMessage(MsgSubmitEvidence)

MsgSubmitEvidenceResponse = _reflection.GeneratedProtocolMessageType('MsgSubmitEvidenceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGSUBMITEVIDENCERESPONSE,
  '__module__' : 'cosmos.evidence.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.evidence.v1beta1.MsgSubmitEvidenceResponse)
  })
_sym_db.RegisterMessage(MsgSubmitEvidenceResponse)


DESCRIPTOR._options = None
_MSGSUBMITEVIDENCE.fields_by_name['evidence']._options = None
_MSGSUBMITEVIDENCE._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='cosmos.evidence.v1beta1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=284,
  serialized_end=403,
  methods=[
  _descriptor.MethodDescriptor(
    name='SubmitEvidence',
    full_name='cosmos.evidence.v1beta1.Msg.SubmitEvidence',
    index=0,
    containing_service=None,
    input_type=_MSGSUBMITEVIDENCE,
    output_type=_MSGSUBMITEVIDENCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)
